/*
Copyright 2020-2023 CAcert Inc.
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package services

import (
	"crypto/rand"

	log "github.com/sirupsen/logrus"
)

func GenerateKey(length int) []byte {
	key := make([]byte, length)

	read, err := rand.Read(key)
	if err != nil {
		log.WithError(err).Fatal("could not generate key")
	}

	if read != length {
		log.WithFields(log.Fields{"read": read, "expected": length}).Fatal("read unexpected number of bytes")
	}

	return key
}
